==> bow-ui-0.5-sources.jar: org/chorem/bow/action/OpenSearchResultAction.java <==
/*
 * #%L
 * bow
 * 
 * $Id: OpenSearchResultAction.java 210 2011-02-18 10:40:36Z vbriand $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-0.5/bow-ui/src/main/java/org/chorem/bow/action/OpenSearchResultAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts2.interceptor.ServletRequestAware;
import org.apache.struts2.interceptor.ServletResponseAware;
import org.chorem.bow.BowBookmark;
import org.chorem.bow.BookmarkActions;
import org.chorem.bow.BookmarkUtils;
import org.chorem.bow.BowConfig;
import org.chorem.bow.BowUtils;
import org.chorem.bow.BowPreference;
import org.nuiton.wikitty.search.Criteria;
import org.nuiton.wikitty.search.PagedResult;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.search.Search;

/**
 * Traite toutes les demandes faite via l'opensearch
 * a:, :, t:, ...
 *
 * @author poussin
 */
public class OpenSearchResultAction extends BowBaseAction implements ServletRequestAware,
ServletResponseAware {
    private static final long serialVersionUID = -1691325797986483856L;
    protected String searchLine;
    protected String token;
    protected String redirectTo;
    protected HttpServletRequest request;
    protected HttpServletResponse response;

    /**
     * @return the searchLine
     */
    public String getSearchLine() {
        return searchLine;
    }

    /**
     * @param searchLine the searchLine to set
     */
    public void setSearchLine(String searchLine) {
        this.searchLine = searchLine;
    }

    /**
     * @return the token
     */
    public String getToken() {
        return token;
    }

    /**
     * @param token the token to set
     */
    public void setToken(String token) {
        this.token = token;
    }

    /**
     * @return the redirectTo
     */
    public String getRedirectTo() {
        return redirectTo;
    }

    @Override
    public void setServletRequest(HttpServletRequest request) {
	this.request = request;
    }

    @Override
    public void setServletResponse(HttpServletResponse response) {
	this.response = response;
    }

    public String execute() {
        BowPreference user = getBowSession().getPreference();
        if (searchLine != null && searchLine.matches("^http://[^ ]*")) {
            redirectTo = BowUtils.redirectTo(searchLine, null);
        } else if (searchLine != null
                && (searchLine.startsWith(":") || searchLine.startsWith("t:"))) {
            //Search on tags

            int index = searchLine.indexOf(":");
            searchLine = searchLine.substring(index + 1); //Suppresses first ":"

            WikittyProxy proxy = getBowProxy();
            Criteria criteria = BookmarkUtils.getBookmarkListCriteriaByUser(user, searchLine);
            criteria = criteria.addSortDescending(BowBookmark.FQ_FIELD_BOWBOOKMARK_CLICK);
            PagedResult<BowBookmark> result = proxy.findAllByCriteria(BowBookmark.class, criteria); //Retrieves bookmarks by search
            BookmarkActions bookmarkActions = BookmarkUtils.createBookmarkActions(request, result, searchLine);
            request.setAttribute("bookmarkActions", bookmarkActions);
            request.setAttribute("token", token);
            redirectTo = BowUtils.redirectTo(searchLine, null);
        } else if (searchLine != null && searchLine.startsWith("f:")) {
            //Fulltext search in bow
            String fullText = searchLine.substring(2);
            WikittyProxy proxy = getBowProxy();
            Criteria criteria;
            if (!fullText.isEmpty()) {
                criteria = Search.query().keyword(fullText).
                        eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_BOWUSER, user.getWikittyId()).criteria().
                        addFacetField(BowBookmark.FQ_FIELD_WIKITTYLABEL_LABELS);
            } else {
                criteria = BookmarkUtils.getBookmarkListCriteriaByUser(user, null);
            }
            PagedResult<BowBookmark> result = proxy.findAllByCriteria(BowBookmark.class, criteria);
            BookmarkActions bookmarkActions = BookmarkUtils.createBookmarkActions(request, result, null);
            request.setAttribute("bookmarkActions", bookmarkActions);
            request.setAttribute("token", token);
            redirectTo = BowUtils.redirectTo(searchLine, null);
        } else if (searchLine != null && searchLine.startsWith("a:")) {
            //Redirects to the requested alias
            searchLine = searchLine.substring(2);
            redirectTo = BowConfig.getInstance().getAliasUrl() + searchLine;
        } else {
            //Search on the chosen search engine
            BowPreference pref = getBowSession().getPreference();

            String searchEngineURL = pref.getSearchEngineUrlResults();
            if (searchEngineURL == null || "".equals(searchEngineURL)) {
                BowConfig config = BowConfig.getInstance();
                searchEngineURL = config.getSearchEngine();
            }
            searchEngineURL = searchEngineURL.replace("{searchTerms}", searchLine);
            searchEngineURL = response.encodeRedirectURL(searchEngineURL);
            redirectTo = searchEngineURL;
        }
        return SUCCESS;
    }
}

==> bow-ui-1.0-sources.jar: org/chorem/bow/action/OpenSearchResultAction.java <==
/*
 * #%L
 * bow
 * 
 * $Id: OpenSearchResultAction.java 285 2011-05-16 13:21:52Z sletellier $
 * $HeadURL: http://svn.chorem.org/svn/bow/tags/bow-1.0/bow-ui/src/main/java/org/chorem/bow/action/OpenSearchResultAction.java $
 * %%
 * Copyright (C) 2010 - 2011 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.chorem.bow.action;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.apache.struts2.interceptor.ServletRequestAware;
import org.apache.struts2.interceptor.ServletResponseAware;
import org.chorem.bow.BowBookmark;
import org.chorem.bow.BookmarkActions;
import org.chorem.bow.BookmarkUtils;
import org.chorem.bow.BowConfig;
import org.chorem.bow.BowUtils;
import org.chorem.bow.BowPreference;
import org.nuiton.wikitty.search.Criteria;
import org.nuiton.wikitty.search.PagedResult;
import org.nuiton.wikitty.WikittyProxy;
import org.nuiton.wikitty.search.Search;

/**
 * Traite toutes les demandes faite via l'opensearch
 * a:, :, t:, ...
 *
 * @author poussin
 */
public class OpenSearchResultAction extends BowBaseAction implements ServletRequestAware,
ServletResponseAware {
    private static final long serialVersionUID = -1691325797986483856L;
    protected String searchLine;
    protected String token;
    protected String redirectTo;
    protected HttpServletRequest request;
    protected HttpServletResponse response;

    /**
     * @return the searchLine
     */
    public String getSearchLine() {
        return searchLine;
    }

    /**
     * @param searchLine the searchLine to set
     */
    public void setSearchLine(String searchLine) {
        this.searchLine = searchLine;
    }

    /**
     * @return the token
     */
    public String getToken() {
        return token;
    }

    /**
     * @param token the token to set
     */
    public void setToken(String token) {
        this.token = token;
    }

    /**
     * @return the redirectTo
     */
    public String getRedirectTo() {
        return redirectTo;
    }

    @Override
    public void setServletRequest(HttpServletRequest request) {
	    this.request = request;
    }

    @Override
    public void setServletResponse(HttpServletResponse response) {
	    this.response = response;
    }

    public String execute() {
        BowPreference user = getBowSession().getPreference();

        if (searchLine != null && searchLine.matches("^http://[^ ]*")) {
            redirectTo = BowUtils.redirectTo(searchLine, null);
        } else if (searchLine != null
                && (searchLine.startsWith(":") || searchLine.startsWith("t:"))) {

            // Search on tags
            int index = searchLine.indexOf(":");
            searchLine = searchLine.substring(index + 1); //Suppresses first ":"

            WikittyProxy proxy = getBowProxy();
            Criteria criteria = BookmarkUtils.getBookmarkListCriteriaByUser(user, searchLine);
            criteria = criteria.addSortDescending(BowBookmark.FQ_FIELD_BOWBOOKMARK_CLICK);
            PagedResult<BowBookmark> result = proxy.findAllByCriteria(BowBookmark.class, criteria); //Retrieves bookmarks by search
            BookmarkActions bookmarkActions = BookmarkUtils.createBookmarkActions(request, result, searchLine);
            request.setAttribute("bookmarkActions", bookmarkActions);
            request.setAttribute("token", token);
            redirectTo = BowUtils.redirectTo(searchLine, null);
        } else if (searchLine != null && searchLine.startsWith("f:")) {
            // Fulltext search in bow
            String fullText = searchLine.substring(2);
            WikittyProxy proxy = getBowProxy();
            Criteria criteria;
            if (!fullText.isEmpty()) {
                criteria = Search.query().keyword(fullText).
                        eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_BOWUSER, user.getWikittyId()).criteria().
                        addFacetField(BowBookmark.FQ_FIELD_WIKITTYLABEL_LABELS);
            } else {
                criteria = BookmarkUtils.getBookmarkListCriteriaByUser(user, null);
            }
            PagedResult<BowBookmark> result = proxy.findAllByCriteria(BowBookmark.class, criteria);
            BookmarkActions bookmarkActions = BookmarkUtils.createBookmarkActions(request, result, null);
            request.setAttribute("bookmarkActions", bookmarkActions);
            request.setAttribute("token", token);
            redirectTo = BowUtils.redirectTo(null, fullText);
        } else if (searchLine != null && searchLine.startsWith("a:")) {
            // Redirects to the requested alias
            String privateAlias = searchLine.substring(2);
            WikittyProxy proxy = getBowProxy();
            Criteria criteria = Search.query()
                    .eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_BOWUSER, user.getWikittyId())
                    .eq(BowBookmark.FQ_FIELD_BOWBOOKMARK_PRIVATEALIAS, privateAlias)
                    .criteria();
            String bookmarkId = proxy.findIdByCriteria(criteria);
            // si on retrouve l'alias prive on l'utilise,
            // sinon on espere qu'il existe un alias public portant ce nom
            if (bookmarkId != null) {
                redirectTo = BowConfig.getAliasUrl() + bookmarkId + ".action";
                if (log.isDebugEnabled()) {
                    log.debug("Private alias found, redirect to: " + redirectTo);
                }
            } else {
                redirectTo = BowConfig.getAliasUrl() + privateAlias + ".action";
                if (log.isDebugEnabled()) {
                    log.debug("Private alias not found, redirect to: " + redirectTo);
                }
            }
        } else {
            // Search on the chosen search engine
            BowPreference pref = getBowSession().getPreference();

            String searchEngineURL = pref.getSearchEngineUrlResults();
            if (StringUtils.isEmpty(searchEngineURL)) {
                searchEngineURL = BowConfig.getSearchEngine();
            }
            searchEngineURL = searchEngineURL.replace("{searchTerms}", searchLine);
            searchEngineURL = response.encodeRedirectURL(searchEngineURL);
            redirectTo = searchEngineURL;
        }
        return SUCCESS;
    }
}
